@@ -296,6 +296,7 @@ impl console::Console for TextConsole {
 /// files.
 pub fn run_repl_loop(dir: &Path) -> io::Result<i32> {
     let console = Rc::from(RefCell::from(TextConsole::from_stdio()?));
-    let store = Rc::from(RefCell::from(FileStore::new(dir)));
-    block_on(endbasic_core::repl::run_repl_loop(console, store, &[]))
+    let store = FileStore::new(dir);
+    let store = Rc::from(RefCell::from(endbasic_core::program::DemoStoreOverlay::new(store)));
+    block_on(endbasic_core::repl::run_repl_loop(console, store))
 }
